package com.persagy.proxy.common.client;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.dmp.basic.config.DigitalFeignConfig;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.proxy.common.constant.DmpUrlConstant;
import com.persagy.proxy.common.entity.DmpResult;
import com.persagy.proxy.common.entity.InstanceUrlParam;
import com.persagy.proxy.common.entity.ObjRelationDTO;
import com.persagy.proxy.common.entity.RelationDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 *@description:数据中台dmp-rwd 物理世界、数据字典、IOT 接口feign
 *@author:lgy
 *@data:2021/8/11 14:56
 */
@FeignClient(name = "dmp-rwd", configuration = DigitalFeignConfig.class)
public interface DmpRwdClient {
    /**
     * @description: 查询关系
     * @param: objectUrlParam
     * @param: relationCriteriaList
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.RELATION_QUERY)
    DmpResult<List<ObjRelationDTO>> queryRelation(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody QueryCriteria criteria);

    /**
     * @description: 查询对象列表
     * @param: objectUrlParam 对象请求url通用参数
     * @param: criteria post请求参数
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.OBJECT_QUERY)
    DmpResult<JSONArray> queryObject(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody JSONObject criteria);
    /**
     * @description: 查询定义类型
     * @param: objectUrlParam 对象请求url通用参数
     * @param: criteria post请求参数
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.DEF_CLASS)
    DmpResult<JSONArray> queryDefClass(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody JSONObject criteria);

    /**
     * @description: 创建对象
     * @param: objectUrlParam 对象请求url通用参数
     * @param: criteria post请求参数
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.OBJECT_CREATE)
    DmpResult createObject(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody JSONArray objectArr);

    /**
     * @description: 更新对象
     * @param: objectUrlParam 对象请求url通用参数
     * @param: criteria post请求参数
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.OBJECT_UPDATE)
    DmpResult updateObject(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody JSONArray objectArr);

    /**
     * @description: 删除对象
     * @param: objectUrlParam 对象请求url通用参数
     * @param: criteria post请求参数
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.OBJECT_DELETE)
    DmpResult deleteObject(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody List<String> objectIdList);
    /**
     * @description: 删除关系
     * @param: objectUrlParam
     * @param: relationCriteriaList
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.RELATION_DELETE)
    DmpResult deleteRelation(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody JSONObject criteria);

    /**
     * @description: 创建关系
     * @param: objectUrlParam
     * @param: relationCriteriaList
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(DmpUrlConstant.RELATION_CREATE)
    DmpResult createRelation(@SpringQueryMap InstanceUrlParam objectUrlParam, @RequestBody List<RelationDTO> createRelationList);
}
